<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>AddPrinterTask</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="551"/>
        <source>URI and driver do not match.</source>
        <translation>L&apos;URI i el controlador no coincideixen.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="553"/>
        <source>Install hplip first and restart the app to install the driver again.</source>
        <translation>Instal·leu primer l&apos;hplip i reinicieu l&apos;aplicació per tornar a instal·lar el controlador.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="561"/>
        <source>Please select an hplip driver and try again.</source>
        <translation>Si us plau, seleccioneu un controlador d&apos;hplip i torneu-ho a provar.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="574"/>
        <source>URI can&apos;t be empty</source>
        <translation>L&apos;URI no pot estar en blanc.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="581"/>
        <source> not found</source>
        <translation>no s&apos;ha trobat</translation>
    </message>
</context>
<context>
    <name>CheckAttributes</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="305"/>
        <source>Check printer settings</source>
        <translation>Comprova els paràmetres de la impressora</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="314"/>
        <source>Checking printer settings...</source>
        <translation>Es comproven els paràmetres de la impressora...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="317"/>
        <source>Success</source>
        <translation>Correcte</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="327"/>
        <source>Failed to get printer attributes, error: </source>
        <translation>Ha fallat obtenir els atributs de la impressora. Error:</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="335"/>
        <source>%1 is disabled</source>
        <translation>%1 està inhabilitada.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="344"/>
        <source>is not accepting jobs</source>
        <translation>no accepta tasques.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="349"/>
        <source>Printer settings are ok</source>
        <translation>Els paràmetres de la impressora són correctes.</translation>
    </message>
</context>
<context>
    <name>CheckConnected</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="211"/>
        <source>Check printer connection</source>
        <translation>Comprova la connexió de la impressora</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="223"/>
        <source>Checking printer connection...</source>
        <translation>Es comproven els paràmetres de la impressora...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="226"/>
        <source>Success</source>
        <translation>Correcte</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="263"/>
        <source>Cannot connect to the printer, error: %1</source>
        <translation>No es pot connectar amb la impressora. Error: %1</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="271"/>
        <source> is not connected, URI: </source>
        <translation> no està connectada. URI: </translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="280"/>
        <source>%1 does not exist</source>
        <translation>%1 no existeix.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="288"/>
        <source>Cannot connect to the printer</source>
        <translation>No es pot connectar amb la impressora.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="294"/>
        <source>The connection is valid</source>
        <translation>La connexió és vàlida.</translation>
    </message>
</context>
<context>
    <name>CheckCupsServer</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="109"/>
        <source>Check CUPS server</source>
        <translation>Comprova el servidor CUPS</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="115"/>
        <source>Checking CUPS server...</source>
        <translation>Es comprova el servidor CUPS...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="117"/>
        <source>CUPS server is invalid</source>
        <translation>El servidor CUPS no és vàlid.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="122"/>
        <source>CUPS server is valid</source>
        <translation>El servidor CUPS és vàlid.</translation>
    </message>
</context>
<context>
    <name>CheckDriver</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="140"/>
        <source>Checking driver...</source>
        <translation>Es comprova el controlador...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="143"/>
        <source>Success</source>
        <translation>Correcte</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="151"/>
        <source>PPD file %1 not found</source>
        <translation>No s&apos;ha trobat el fitxer PPD %1.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="161"/>
        <source>The driver is damaged</source>
        <translation>El controlador està malmès.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="177"/>
        <source>Driver filter %1 not found</source>
        <translation>No s&apos;ha trobat el filtre del controlador %1.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="189"/>
        <source>%1 is not installed, cannot print now</source>
        <translation>%1 no està instal·lada. Ara no pot imprimir.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="195"/>
        <source>Driver is valid</source>
        <translation>El controlador és vàlid.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="201"/>
        <source>Check driver</source>
        <translation>Comprova el controlador</translation>
    </message>
</context>
<context>
    <name>CupsMonitor</name>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="99"/>
        <source>Queuing</source>
        <translation>A la cua</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="100"/>
        <source>Paused</source>
        <translation>En pausa</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="101"/>
        <source>Printing</source>
        <translation>S&apos;imprimeix</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="102"/>
        <source>Stopped</source>
        <translation>Aturada</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="103"/>
        <source>Canceled</source>
        <translation>Cancel·lada</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="104"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="105"/>
        <source>Completed</source>
        <translation>Completada</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="369"/>
        <source>%1 timed out, reason: %2</source>
        <translation>%1 ha esgotat el temps d&apos;espera. Raó: %2</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="383"/>
        <source>%1 has been sent to the printer, please take away the paper in time!</source>
        <translation>%1 s&apos;ha enviat a la impressora. Si us plau, traieu-ne el paper a temps!</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="385"/>
        <source>%1 %2, reason: %3</source>
        <translation>%1 %2, raó: %3</translation>
    </message>
</context>
<context>
    <name>DriverManager</name>
    <message>
        <location filename="../../Common/vendor/zdrivermanager.cpp" line="1031"/>
        <source>EveryWhere driver</source>
        <translation>Controlador EveryWhere</translation>
    </message>
</context>
<context>
    <name>InstallDriver</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="373"/>
        <source>Failed to find the driver solution: %1, error: %2</source>
        <translation>Ha fallat trobar la solució del controlador: %1. Error: %2</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="384"/>
        <source>The solution is invalid</source>
        <translation>La solució no és vàlida.</translation>
    </message>
</context>
<context>
    <name>InstallInterface</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="251"/>
        <source>is invalid</source>
        <translation>no és vàlid</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="280"/>
        <source>Failed to install the driver by calling dbus interface</source>
        <translation>Ha fallat instal·lar el controlador cridant la interfície dbus.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="325"/>
        <source>Failed to install %1</source>
        <translation>Ha fallat instal·lar %1.</translation>
    </message>
</context>
<context>
    <name>JobManager</name>
    <message>
        <location filename="../../Common/zjobmanager.cpp" line="307"/>
        <source> not found</source>
        <translation>no s&apos;ha trobat</translation>
    </message>
</context>
<context>
    <name>PrinterTestJob</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="370"/>
        <source>Check test page printing</source>
        <translation>Comproveu la impressió de la pàgina de mostra.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="424"/>
        <source>Printing test page...</source>
        <translation>S&apos;imprimeix una pàgina de mostra...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>Print Manager</source>
        <translation>Gestor d&apos;impressió</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Print Manager is a printer management tool, which supports adding and removing printers, managing print jobs and so on.</source>
        <translation>El Gestor d&apos;impressió és una eina de gestió d&apos;impressió que admet afegir i eliminar impressores, gestionar les tasques d&apos;impressió i moltes altres coses.</translation>
    </message>
    <message>
        <location filename="../../Common/common.cpp" line="154"/>
        <source>%1 not found, please ask the administrator for help, or enter the printer IP address in URI of Properties.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>USBThread</name>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="260"/>
        <source>Configuring the printer %1 ...</source>
        <translation>Es configura la impressors %1...</translation>
    </message>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="306"/>
        <source>Configuration successful. Click to view %1.</source>
        <translation>Configuració correcta. Cliqueu per veure-ho: %1.</translation>
    </message>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="310"/>
        <source>Configuration failed. Click to add the printer %1.</source>
        <translation>Ha fallat la configuració. Cliqueu per afegir la impressora %1.</translation>
    </message>
</context>
</TS>